@@ -2,23 +2,21 @@
 
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Copyright (C) 2002-2013 Guido Flohr <guido@imperia.net>,
+# Copyright (C) 2002-2015 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
-# This program is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Library General Public License as published
-# by the Free Software Foundation; either version 2, or (at your option)
-# any later version.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
 
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 
-# You should have received a copy of the GNU Library General Public 
-# License along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
-# USA.
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Locale::Messages;
 
@@ -26,20 +24,34 @@ use strict;
 
 use vars qw ($package @EXPORT_OK %EXPORT_TAGS @ISA $VERSION);
 
-$VERSION = '1.23';
+$VERSION = '1.24';
 
 # Try to load the C version first.
 $package = 'gettext_xs';
-my $can_xs = 1;
 eval <<'EOF';
 require Locale::gettext_xs; 
 my $version = Locale::gettext_xs::__gettext_xs_version();
 die "Version: version mismatch ($VERSION vs. $version)" unless $version eq $VERSION;
 EOF
-if ($@) {
-    $package = 'gettext_pp';
-	undef $can_xs;
-    require Locale::gettext_pp;
+my $no_xs = $@;
+
+# There are systems where setlocale() and the LC_ constants are not
+# defined at all, see https://rt.cpan.org/Ticket/Display.html?id=98109
+#
+# On such systems, we always fall back to gettext_dumb.
+if ($no_xs) {
+    eval {
+        require POSIX;
+        # void
+        POSIX::setlocale(POSIX::LC_ALL());
+    };
+    if ($@) {
+        $package = 'gettext_dumb';
+        require Locale::gettext_dumb;
+    } else {
+        $package = 'gettext_pp';
+        require Locale::gettext_pp;
+    }
 }
 		
 require Exporter;
@@ -91,6 +103,7 @@ require Exporter;
 				 bind_textdomain_codeset
 				 bind_textdomain_filter
                  nl_putenv
+                 setlocale
 				 LC_CTYPE
 				 LC_NUMERIC
 				 LC_TIME
@@ -174,7 +187,7 @@ sub select_package {
         $pkg = $compatibility;
     }
 
-    if (!$can_xs && 'gettext_xs' eq $pkg) {
+    if ($no_xs && 'gettext_xs' eq $pkg) {
         $pkg = 'gettext_pp';
     }
 
@@ -340,9 +353,14 @@ sub dcnpgettext($$$$$$) {
     $cb->[0] (&$function, $cb->[1]);
 }
 
-sub nl_putenv($) {
-    my $cb = $filters{$_[0]} ||= [ \&turn_utf_8_off ];
+sub setlocale($;$) {
+    my $function = "Locale::${package}::setlocale";
+    
+    no strict 'refs';
+    &$function;
+}
 
+sub nl_putenv($) {
     my $function = "Locale::${package}::nl_putenv";
     
     no strict 'refs';
@@ -739,6 +757,9 @@ variable B<OUTPUT_CHARSET> to "utf-8".  Additionally you should
 call bind_textdomain_codeset() with "utf-8" as the second
 argument.
 
+Steven Haryanto has written a module Locale::TextDomain::UTF8(3pm)
+that addresses the same problem.
+
 This function has been introduced in libintl-perl 1.16 and it is
 B<not> part of the standard gettext API.
 
@@ -780,7 +801,7 @@ or "gettext_xs" and use a completely different backend.  It is the caller's
 responsability to make sure that the selected package offers the same
 interface as the two standard packages.
 
-One package that offers that functionality is Locale::gettext_dump(3pm).
+One package that offers that functionality is Locale::gettext_dumb(3pm).
 
 =item B<nl_putenv ENVSPEC>
 
@@ -841,10 +862,30 @@ operates on C<%ENV>, under Windows it will call the C library
 function _putenv() (after doing some cleanup to its arguments),
 before manipulating C<%ENV>.
 
-Please note, that you C<%ENV> is updated by nl_putenv() automatically.
+Please note, that your C<%ENV> is updated by nl_putenv() automatically.
 
 The function has been introduced in libintl-perl version 1.10.
 
+=item setlocale
+
+Modifies and queries program's locale, see the documentation for setlocale()
+in POSIX(3pm) instead.
+
+On some systems, when using GNU gettext, a call from C to setlocale() is
+- with the help of the C preprocessor - really a call to libintl_setlocale(),
+which is in turn a wrapper around the system setlocale(3).  Failure to call
+libintl_setlocale() may lead to certain malfunctions.  On such systems,
+B<Locale::Messages::setlocale()> will call the wrapper libintl_setlocale().
+If you want to avoid problems, you should therefore always call
+the setlocale() implementation in Locale::Messages(3pm).
+
+See L<https://rt.cpan.org/Public/Bug/Display.html?id=83980> or
+L<https://savannah.gnu.org/bugs/?38162>, and 
+L<https://savannah.gnu.org/bugs/?func=detailitem&item_id=44645> for a discussion
+of the problem.
+
+The function has been introduced in libintl-perl version 1.24.
+
 =back
 
 =head1 CONSTANTS
@@ -1011,16 +1052,14 @@ See Locale::TextDomain(3) for much simpler ways.
 
 =head1 AUTHOR
 
-Copyright (C) 2002-2013, Guido Flohr E<lt>guido@imperia.netE<gt>, all
+Copyright (C) 2002-2015, Guido Flohr E<lt>guido.flohr@cantanea.comE<gt>, all
 rights reserved.  See the source code for details.
 
-This software is contributed to the Perl community by Imperia 
-(L<http://www.imperia.net/>).
-
 =head1 SEE ALSO
 
 Locale::TextDomain(3pm), Locale::gettext_pp(3pm), Encode(3pm),
-perllocale(3pm), POSIX(3pm), perl(1), gettext(1), gettext(3)
+Locale::TextDomain::UTF8(3pm), perllocale(3pm), POSIX(3pm), perl(1), 
+gettext(1), gettext(3)
 
 =cut
 
