@@ -3,23 +3,21 @@
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
 # Pure Perl implementation of Uniforum message translation.
-# Copyright (C) 2002-2013 Guido Flohr <guido@imperia.net>,
+# Copyright (C) 2002-2015 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
-# This program is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Library General Public License as published
-# by the Free Software Foundation; either version 2, or (at your option)
-# any later version.
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
 
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Library General Public License for more details.
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
 
-# You should have received a copy of the GNU Library General Public
-# License along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
-# USA.
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Locale::gettext_pp;
 
@@ -167,6 +165,7 @@ use vars qw (%EXPORT_TAGS @EXPORT_OK @ISA $VERSION);
     			 bindtextdomain
     			 bind_textdomain_codeset
                  nl_putenv
+                 setlocale
     			 LC_CTYPE
     			 LC_NUMERIC
     			 LC_TIME
@@ -480,6 +479,11 @@ sub nl_putenv ($)
     return 1;
 }
 
+sub setlocale($;$) {
+	require POSIX;
+	&POSIX::setlocale;
+}
+
 sub __load_domain
 {
     my ($domainname, $category, $category_name, $locale) = @_;
@@ -948,6 +952,10 @@ See L<Locale::Messages/FUNCTIONS>.
 
 See L<Locale::Messages/FUNCTIONS>.
 
+=item B<setlocale>
+
+See L<Locale::Messages/FUNCTIONS>.
+
 =back
 
 =head1 CONSTANTS
@@ -1059,12 +1067,9 @@ Imports the locale category constants:
 
 =head1 AUTHOR
 
-Copyright (C) 2002-2013, Guido Flohr E<lt>guido@imperia.netE<gt>, all
+Copyright (C) 2002-2015, Guido Flohr E<lt>guido.flohr@cantanea.comE<gt>, all
 rights reserved.  See the source code for details.
 
-This software is contributed to the Perl community by Imperia 
-(L<http://www.imperia.net/>).
-
 =head1 SEE ALSO
 
 Locale::TextDomain(3pm), Locale::Messages(3pm), Encode(3pm),
